@@ -1,10 +1,12 @@
-`plot3d.prcurve` <- function(x, data, scale = FALSE,
-                             choices = 1:3, display = "sites",
+`Plot3d` <- function(x, choices = 1:3, display = "sites",
                              scaling = 0,
                              lcol = "darkorange", lwd = 2,
                              decorate = TRUE,
                              xlab = NULL, ylab = NULL, zlab = NULL,
                              main = NULL, ...) {
+    if (!require("rgl")) {
+        stop("Package 'rgl' required but not installed.\nRun\n\t'install.packages(\"rgl\")\nto use 'Plot3d()'.")
+    }
     ## check choices
     if(!missing(choices)) {
         lc <- length(choices)
@@ -17,7 +19,8 @@
         }
     }
     ## do ordination
-    ord <- rda(data, scale = scale)
+    ## ord <- rda(x$data, scale = scale)
+    ord <- x$ordination ## this is now stored
     ## process labels
     if(missing(xlab) || is.null(xlab))
         xlab <- paste0("PC", choices[1])
@@ -29,9 +32,9 @@
             ...)
     pred <- predict(ord, x[["s"]], type = "wa",
                     scaling = scaling)[x[["tag"]], ]
-    lines3d(pred[,1], pred[,2], pred[,3], col = lcol, lwd = lwd, ...)
+    rgl::lines3d(pred[,1], pred[,2], pred[,3], col = lcol, lwd = lwd, ...)
     if(decorate) {
-        decorate3d(xlab = xlab, ylab = ylab, zlab = zlab, ...)
+        rgl::decorate3d(xlab = xlab, ylab = ylab, zlab = zlab, ...)
     }
     invisible()
 }
