@@ -48,6 +48,7 @@ double xy_euclidean(double *x, double *y, int nr1, int nr2,
     
     count = 0;
     dist = 0.0;
+
     for (j=0; j<nc; j++) {
 	if (R_FINITE(x[i1]) && R_FINITE(y[i2])) {
 	    dev = x[i1] - y[i2];
@@ -160,6 +161,8 @@ double xy_chi_square(double *x, double *y, int nr1, int nr2,
     
     count = 0;
     dist = 0.0;
+    dev = 0.0;
+
     for (j=0; j<nc; j++) {
 	if (R_FINITE(x[i1]) && R_FINITE(y[i2])) {
 	    if(x[i1] != 0 || y[i2] != 0) {
@@ -186,6 +189,8 @@ double xy_sq_chi_square(double *x, double *y, int nr1, int nr2,
 	
     count = 0;
     dist = 0.0;
+    dev = 0.0;
+
     for (j=0; j<nc; j++) {
 	if (R_FINITE(x[i1]) && R_FINITE(y[i2])) {
 	    if(x[i1] != 0 || y[i2] != 0) {
@@ -306,7 +311,7 @@ double xy_alt_gower(double *x, double *y, int nr1, int nr2,
 
 /* Driver */
 
-static double (*distfun)(double*, double*, int, int, int, 
+static double (*xy_distfun)(double*, double*, int, int, int, 
 			 int, int);
 
 void xy_distance(double *x, double *y, int *nr1, int *nr2,
@@ -315,37 +320,37 @@ void xy_distance(double *x, double *y, int *nr1, int *nr2,
     int i, j, ij;
     switch(*method) {
     case EUCLIDEAN:
-	distfun = xy_euclidean;
+	xy_distfun = xy_euclidean;
 	break;
     case SQEUCLIDEAN:
-	distfun = xy_sq_euclidean;
+	xy_distfun = xy_sq_euclidean;
 	break;
     case CHORD:
-	distfun = xy_chord;
+	xy_distfun = xy_chord;
 	break;
     case SQCHORD:
-	distfun = xy_sq_chord;
+	xy_distfun = xy_sq_chord;
 	break;
     case BRAY:
-	distfun = xy_bray;
+	xy_distfun = xy_bray;
 	break;
     case CHISQUARE:
-	distfun = xy_chi_square;
+	xy_distfun = xy_chi_square;
 	break;
     case SQCHISQUARE:
-	distfun = xy_sq_chi_square;
+	xy_distfun = xy_sq_chi_square;
 	break;
     case INFORMATION:
-	distfun = xy_information;
+	xy_distfun = xy_information;
 	break;
     case MANHATTAN:
-	distfun = xy_manhattan;
+	xy_distfun = xy_manhattan;
 	break;
     case GOWER:
-	distfun = xy_gower;
+	xy_distfun = xy_gower;
 	break;
     case ALTGOWER:
-	distfun = xy_alt_gower;
+	xy_distfun = xy_alt_gower;
 	break;
     default:
 	error("Unknown distance in the internal C function");
@@ -354,7 +359,7 @@ void xy_distance(double *x, double *y, int *nr1, int *nr2,
     ij = 0;
     for (j=0; j < *nr1; j++)
 	for (i=0; i < *nr2; i++) {
-	    d[ij++] = distfun(x, y, *nr1, *nr2, *nc, j, i);
+	    d[ij++] = xy_distfun(x, y, *nr1, *nr2, *nc, j, i);
 	}
 }
 
@@ -582,84 +587,89 @@ double xy_MIXED(double *x, double *y, int nr1, int nr2,
 		int nc, int i1, int i2, int *vtype,
 		double *weights, double *R, double wsum)
 {
-    double dist, dev;
-    int count, j;
+  double dist, dev;
+  int count, j;
+  
+  count = 0;
+  dist = 0.0;
+  wsum = 0.0;
+  //curweights = weights; /* current weights */
     
-    count = 0;
-    dist = 0.0;
-    wsum = 0.0;
-    //curweights = weights; /* current weights */
-    
-    for (j=0; j<nc; j++) {
-	if (R_FINITE(x[i1]) && R_FINITE(y[i2])) {
-	    if(vtype[j] == 1) { // Symmetric binary
-		dev = (x[i1] == y[i2]) ? 1 : 0;
-		dist += dev * weights[j];
-	    }
-	    if(vtype[j] == 2) { // Asymmetric binary
-		if((x[i1] != 0) || (y[i2] != 0)) {
-		    // both x and y not zero for this variables
-		    dev = (x[i1] == y[i2]) ? 1 : 0;
-		    dist += dev * weights[j];
-		} else {
-		    /* set jth current weight to zero and do not
-		       increment dist as ignoring double zero
-		       We actually subtract the weight as it gets added
-		       later on.
-		    */
-		    wsum -= weights[j];
-		}
-	    }
-	    if(vtype[j] == 3) { // Nominal
-		dev = (x[i1] == y[i2]) ? 1 : 0;
-		dist += dev * weights[j];
-	    }
-	    if(vtype[j] == 4) { // Ordinal
-		dev = (x[i1] == y[i2]) ? 1 : 0;
-		dist += dev * weights[j];
-		break;
-		/* ordinal data current not handled 
-		 * so don't call this yet
-		 */
-		/* switch(ord) {
-		   case 1: { // classic gower as per nominal
-		   dev = (x[i1] == y[i2]) ? 1 : 0;
-		   dist += dev * weights[j];
-		   break;
-		   }
-		   case 2: { // podanis rank version
-		   if(x[i1] == y[i2]) {
-		   dev = 1;
-		   } else {
-		   dev = (fabs(x[i1] - y[i2])) / 
-		   (R[j] - (tmax - 1)/2 - (tmin - 1)/2);
-		   }
-		   break;
-		   }
-		   case 3: { // podanis metric version treat as Quantitative??
-		   dev = 1 - (fabs(x[i1] - y[i2]) / R[j]);
-		   dist += dev * weights[j];
-		   break;
-		   }
-		   default: {
-		   dist += 0;
-		   break;
-		   }
-		   }*/
-	    }
-	    if(vtype[j] == 5) { // Quantitative
-		dev = 1 - (fabs(x[i1] - y[i2]) / R[j]);
-		dist += dev * weights[j];
-	    }
-	    count++;
-	    // only summing weights for non-NA comparisons
-	    wsum += weights[j];
+  for (j=0; j<nc; j++) {
+    if (R_FINITE(x[i1]) && R_FINITE(y[i2])) {
+      // Symmetric binary
+      if(vtype[j] == 1) {
+	dev = (x[i1] == y[i2]) ? 1 : 0;
+	dist += dev * weights[j];
+      }
+      // Asymmetric binary
+      if(vtype[j] == 2) {
+	if((x[i1] != 0) || (y[i2] != 0)) {
+	  // both x and y not zero for this variables
+	  dev = (x[i1] == y[i2]) ? 1 : 0;
+	  dist += dev * weights[j];
+	} else {
+	  /* set jth current weight to zero and do not
+	     increment dist as ignoring double zero
+	     We actually subtract the weight as it gets added
+	     later on.
+	  */
+	  wsum -= weights[j];
 	}
-	i1 += nr1;
-	i2 += nr2;
+      }
+      // Nominal
+      if(vtype[j] == 3) {
+	dev = (x[i1] == y[i2]) ? 1 : 0;
+	dist += dev * weights[j];
+      }
+      // Ordinal
+      if(vtype[j] == 4) {
+	dev = (x[i1] == y[i2]) ? 1 : 0;
+	dist += dev * weights[j];
+	break;
+	/* ordinal data current not handled 
+	 * so don't call this yet
+	 */
+	/* switch(ord) {
+	   case 1: { // classic gower as per nominal
+	   dev = (x[i1] == y[i2]) ? 1 : 0;
+	   dist += dev * weights[j];
+	   break;
+	   }
+	   case 2: { // podanis rank version
+	   if(x[i1] == y[i2]) {
+	   dev = 1;
+	   } else {
+	   dev = (fabs(x[i1] - y[i2])) / 
+	   (R[j] - (tmax - 1)/2 - (tmin - 1)/2);
+	   }
+	   break;
+	   }
+	   case 3: { // podanis metric version treat as Quantitative??
+	   dev = 1 - (fabs(x[i1] - y[i2]) / R[j]);
+	   dist += dev * weights[j];
+	   break;
+	   }
+	   default: {
+	   dist += 0;
+	   break;
+	   }
+	   }*/
+      }
+      // Quantitative
+      if(vtype[j] == 5) {
+	dev = 1 - (fabs(x[i1] - y[i2]) / R[j]);
+	dist += dev * weights[j];
+      }
+      count++;
+      // only summing weights for non-NA comparisons
+      wsum += weights[j];
     }
-    if (count == 0) return NA_REAL;
-    return 1 - (dist / wsum);
+    i1 += nr1;
+    i2 += nr2;
+  }
+  if (count == 0) return NA_REAL;
+  return 1 - (dist / wsum);
 }
 
 double xy_calcTI(double *x, double *y, int nr1, int nr2, int nc, int i1, int i2)
